@@ -6,7 +6,7 @@ use Clustericious::Log;
 use Data::Dumper;
 
 # ABSTRACT: build crud routes easily
-our $VERSION = '0.9941'; # VERSION 
+our $VERSION = '0.9942'; # VERSION 
 
 
 use Sub::Exporter -setup => {
@@ -54,7 +54,7 @@ sub _build_read {
         my @keys = split /\//, $self->stash->{key};
         TRACE "read $table (@keys)";
         my $obj   = $finder->find_object($table,@keys)
-            or return $self->render_not_found( join '/',$table,@keys );
+            or return $self->reply->not_found( join '/',$table,@keys );
         $self->app->log->debug("Viewing $table @keys");
 
         $self->stash(autodata => $obj->as_hash);
@@ -72,7 +72,7 @@ sub _build_delete {
         my @keys = split /\//, $self->stash->{key};
         TRACE "delete $table (@keys)";
         my $obj   = $finder->find_object($table,@keys)
-            or return $self->render_not_found( join '/',$table,@keys );
+            or return $self->reply->not_found( join '/',$table,@keys );
         $self->app->log->debug("Deleting $table @keys");
 
         $obj->delete or LOGDIE($obj->errors);
@@ -94,7 +94,7 @@ sub _build_update {
         my @keys = split /\//, $self->stash->{key};
 
         my $obj = $finder->find_object($table, @keys)
-            or return $self->render_not_found( join '/',$table,@keys );
+            or return $self->reply->not_found( join '/',$table,@keys );
 
         TRACE "Updating $table @keys";
         $self->parse_autodata;
@@ -147,7 +147,7 @@ sub _build_list {
 
         $self->app->log->debug("Listing $table");
         my $object_class = $finder->find_class($table)
-            or return $self->render_not_found( $table );
+            or return $self->reply->not_found( $table );
         my $pkey = $object_class->meta->primary_key;
         my $manager = $object_class . '::Manager';
 
@@ -188,7 +188,7 @@ Clustericious::RouteBuilder::CRUD - build crud routes easily
 
 =head1 VERSION
 
-version 0.9941
+version 0.9942
 
 =head1 SYNOPSIS
 
